@@ -1,4 +1,5 @@
 import struct
+from ..tools import pad
 from .orpcthat import ORPCTHAT
 from .objref_standard import ObjRefStandard
 from .interface import NdrInterface
@@ -24,7 +25,7 @@ class NTLMLoginResponse(NdrInterface):
         offset += self.FMT1_32_SZ
 
         self.objref = ObjRefStandard.from_data(data, offset, size)
-        offset += size
+        offset += size + pad(size)
 
         self.error_code, = struct.unpack_from('<L', data, offset)
         assert self.error_code == 0, f'error code: {self.error_code}'
