@@ -30,7 +30,9 @@ class Protocol(asyncio.Protocol):
         self._auth_level: int = None
         self._flags = None
         self._client_seal: Optional[Callable] = None
+        self._client_sign: Optional[Callable] = None
         self._server_seal: Optional[Callable] = None
+        self._server_sign: Optional[Callable] = None
         self._iid = None
 
     @staticmethod
@@ -130,7 +132,6 @@ class Protocol(asyncio.Protocol):
         for req in self._requests.values():
             if req.fut is not None:
                 req.fut.cancel()
-        self._requests.clear()
 
         # Clear interface
         self._interface = None
